#include "logo.h"
#include <string>

void Logo::Init(int width, int height, std::string title, int maxTimer)
{
    SetWindowSize(width, height); 
    SetWindowTitle(title.c_str());

    logoPositionX = width/2 - 168;
    logoPositionY = height/2 - 168;
}

void Logo::Tick()
{
    BeginDrawing();    
    Update();
    Draw();
    EndDrawing(); 
}

// 업데이트 메서드
void Logo::Update()
{
        if (state == 0)                 // State 0: Small box blinking
        {
            framesCounter++;

            if (framesCounter == 120)
            {
                state = 1;
                framesCounter = 0;      // Reset counter... will be used later...
            }
        }
        else if (state == 1)            // State 1: Top and left bars growing
        {
            topSideRecWidth += 4;
            leftSideRecHeight += 4;

            if (topSideRecWidth == 296) state = 2;
        }
        else if (state == 2)            // State 2: Bottom and right bars growing
        {
            bottomSideRecWidth += 4;
            rightSideRecHeight += 4;

            if (bottomSideRecWidth == 296) state = 3;
        }
        else if (state == 3)            // State 3: Letters appearing (one by one)
        {
            framesCounter++;

            if (framesCounter/12)       // Every 12 frames, one more letter!
            {
                lettersCount++;
                framesCounter = 0;
            }

            if (lettersCount >= 10)     // When all letters have appeared, just fade out everything
            {
                alpha -= 0.02f;

                if (alpha <= 0.0f)
                {
                    alpha = 0.0f;
                    state = 4;
                    framesCounter = 0;
                    
                }
            }
        }else if (state == 4)
        {
            framesCounter++;

            if (framesCounter == 60)
            {
                framesCounter = 0;      // Reset counter... will be used later...
                nextStage = true;
            }
        }

}

// 그리기 메서드
void Logo::Draw()
{
    ClearBackground(DARKBLUE);

    if (state == 0)
    {
        if ((framesCounter/15)%2) DrawRectangle(logoPositionX, logoPositionY, 16, 16, BLACK);
    }
    else if (state == 1)
    {
        DrawRectangle(logoPositionX, logoPositionY, topSideRecWidth, 16, BLACK);
        DrawRectangle(logoPositionX, logoPositionY, 16, leftSideRecHeight, BLACK);
    }
    else if (state == 2)
    {
        DrawRectangle(logoPositionX, logoPositionY, topSideRecWidth, 16, BLACK);
        DrawRectangle(logoPositionX, logoPositionY, 16, leftSideRecHeight, BLACK);

        DrawRectangle(logoPositionX + 280, logoPositionY, 16, rightSideRecHeight, BLACK);
        DrawRectangle(logoPositionX, logoPositionY + 280, bottomSideRecWidth, 16, BLACK);
    }
    else if (state == 3)
    {
        DrawRectangle(logoPositionX, logoPositionY, topSideRecWidth, 16, Fade(BLACK, alpha));
        DrawRectangle(logoPositionX, logoPositionY + 16, 16, leftSideRecHeight - 32, Fade(BLACK, alpha));

        DrawRectangle(logoPositionX + 280, logoPositionY + 16, 16, rightSideRecHeight - 32, Fade(BLACK, alpha));  // 280 means width - 16
        DrawRectangle(logoPositionX, logoPositionY + 280, bottomSideRecWidth, 16, Fade(BLACK, alpha));

        DrawRectangle(GetScreenWidth()/2 - 152, GetScreenHeight()/2 - 152, 264, 264, Fade(RAYWHITE, alpha));  // 152 means 168(padding) - 16(width or height)

        DrawText(TextSubtext("DK Tetris", 0, lettersCount), GetScreenWidth()/2 - 64, GetScreenHeight()/2 + 48, 32, Fade(BLACK, alpha));
    }else if (state == 4)
    {
        DrawRectangle(logoPositionX, logoPositionY, topSideRecWidth, 16, BLACK);
        DrawRectangle(logoPositionX, logoPositionY + 16, 16, leftSideRecHeight - 32, BLACK);

        DrawRectangle(logoPositionX + 280, logoPositionY + 16, 16, rightSideRecHeight - 32, BLACK);
        DrawRectangle(logoPositionX, logoPositionY + 280, bottomSideRecWidth, 16, BLACK);

        DrawRectangle(GetScreenWidth()/2 - 152, GetScreenHeight()/2 - 152, 264, 264, RAYWHITE);

        DrawText("DK Tetris", GetScreenWidth()/2 - 64, GetScreenHeight()/2 + 48, 32, BLACK);
    }

}